--[[
	Author: GrimNotepad
--]]

local ADDON_NAME, L = ...;
local VERSION = GetAddOnMetadata(ADDON_NAME, "Version")

local buttonlabel = "Quests: "
local numquests = 0
local showmax = true
local inccamp = true
local usesum = false
local maxquests = 25
local Color = {}
Color.WHITE = "|cFFFFFFFF"
Color.RED = "|cFFDC2924"
Color.YELLOW = "|cFFFFF244"
Color.GREEN = "|cFF3DDC53"

local function OnClick(self, button)
	if (button == "LeftButton") then
		OpenQuestLog();
	end
end

-----------------------------------------------
local menus = {
	{ type = "rightSideToggle" },
	{ type = "toggle", text = "Include Campaigns", var = "IncCamp", def = true, keepShown = true },
	{ type = "toggle", text = "Show Max", var = "ShowMax", def = true, keepShown = true },
	{ type = "toggle", text = "Use Summary", var = "UseSum", def = false, keepShown = true },
}

local eventsTable = {
	PLAYER_ENTERING_WORLD = function(self)
		maxquests = C_QuestLog.GetMaxNumQuestsCanAccept()
		self:UnregisterEvent("PLAYER_ENTERING_WORLD")
		TitanPanelButton_UpdateButton(self.registry.id)
	end,
	QUEST_LOG_UPDATE = function(self)
		TitanPanelButton_UpdateButton(self.registry.id)
	end
}


function GetButtonText(self, id)
	showmax = TitanGetVar(id, "ShowMax")
	inccamp = TitanGetVar(id, "IncCamp")
	usesum = TitanGetVar(id, "UseSum")
	local campquests, numquests, numquests_display, maxquests_display =  0, 0, 0, maxquests
	local i = 1
	maxquests_display = maxquests
	while C_QuestLog.GetInfo(i) do
	   local info = C_QuestLog.GetInfo(i)
	   if  not info.isHeader and not info.isBounty and not info.isHidden then
	      if info.campaignID ~= nil then
	         campquests = campquests + 1
	      end
	      if info.campaignID == nil then
	         numquests = numquests + 1
	      end
	   end    
	   i = i + 1
	end	
	numquests_display = numquests
	
	if inccamp and usesum then
	   numquests_display = campquests + numquests
	   maxquests_display = maxquests + campquests
	end
	local RetVal = GetQuestCountColor(numquests, maxquests) .. numquests_display .. "|r"
	
	if showmax then
	   RetVal = RetVal .. "/" .. maxquests_display
	end
	if inccamp and not usesum then
	   RetVal = RetVal .. " |cFF00CCFF(" .. campquests .. ")"
    end
	return buttonlabel, RetVal
end

function GetTooltipText(self, id)
	return "Displays the number of quests you have."
end

-----------------------------------------------
LibStub("Elib-4.0").Register({
	id = "TitanQuests",
	name = "Titan Quests",
	tooltip = "Titan Quests",
	icon = "Interface\\Icons\\achievement_quests_completed_07.blp",
	category = "Information",
	version = VERSION,
	getButtonText = GetButtonText,
	getTooltipText = GetTooltipText,
	eventsTable = eventsTable,
	menus = menus,
	onClick = OnClick
})

function GetQuestCountColor(count,max)
	local pct = math.ceil(100 * (count / max))
	if pct > 99 then
		return Color.RED
	elseif pct > 80 then
		return Color.YELLOW
	elseif pct > 0 then
		return Color.GREEN
	else
		return Color.WHITE
	end
end